"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.components = void 0;
var _index = require("../tokens/index.js");
var _colors = require("./colors.js");
var _effects = require("./effects.js");
var _spacing = require("./spacing.js");
var _typography = require("./typography.js");
const theme = {
  ..._colors.colors,
  ..._effects.effects,
  ..._spacing.spacing,
  ..._typography.typography
};
const components = {
  button: {
    transaction: {
      container: {
        color: {
          default: theme.background.transaction,
          hover: theme.backgroundState.transaction.hover,
          active: theme.backgroundState.transaction.active,
          disable: theme.backgroundState.transaction.disable
        },
        border: {
          default: _index.tokens.null['100'],
          hover: _index.tokens.null['100'],
          active: _index.tokens.null['100'],
          disable: _index.tokens.null['100']
        }
      },
      text: {
        color: {
          default: theme.content.base,
          hover: theme.content.base,
          active: theme.content.base,
          disabel: theme.contentState.base.disable
        }
      },
      icon: {
        color: {
          default: theme.content.base,
          hover: theme.content.base,
          active: theme.content.base,
          disabel: theme.contentState.base.disable
        }
      }
    },
    sm: {
      generic: {
        paddingHorizontal: _index.tokens.padding.S,
        paddingVertical: _index.tokens.padding.S,
        gap: _index.tokens.padding.S,
        textLabel: theme.desktop.button.tertiary,
        borderRadius: _index.tokens.borderRadius.XS
      },
      icon: {
        size: '18px'
      },
      ghost: {
        paddingHorizontal: _index.tokens.padding.S,
        paddingVertical: _index.tokens.padding.S,
        gap: _index.tokens.padding.S,
        textLabel: theme.desktop.button.tertiary,
        borderRadius: _index.tokens.borderRadius.XS
      }
    },
    md: {
      generic: {
        paddingHorizontal: _index.tokens.padding.M,
        paddingVertical: _index.tokens.padding.M,
        gap: _index.tokens.padding.M,
        borderRadius: _index.tokens.borderRadius.XS,
        textLabel: theme.desktop.button.secondary
      },
      icon: {
        size: '24px'
      },
      ghost: {
        paddingHorizontal: _index.tokens.padding.M,
        paddingVertical: _index.tokens.padding.M,
        gap: _index.tokens.padding.M,
        textLabel: theme.desktop.button.secondary,
        borderRadius: _index.tokens.borderRadius.XS
      }
    },
    lg: {
      generic: {
        paddingHorizontal: _index.tokens.padding.L,
        paddingVertical: _index.tokens.padding.L,
        gap: _index.tokens.padding.L,
        borderRadius: _index.tokens.borderRadius.XS,
        textLabel: theme.desktop.button.primary
      },
      icon: {
        size: '24px'
      },
      ghost: {
        paddingHorizontal: _index.tokens.padding.L,
        paddingVertical: _index.tokens.padding.L,
        gap: _index.tokens.padding.L,
        textLabel: theme.desktop.button.primary,
        borderRadius: _index.tokens.borderRadius.XS
      }
    },
    brand: {
      container: {
        color: {
          default: theme.background.accent,
          hover: theme.backgroundState.accent.hover,
          active: theme.backgroundState.accent.active,
          disable: theme.backgroundState.accent.disable
        },
        border: {
          default: _index.tokens.null['100'],
          hover: _index.tokens.null['100'],
          active: _index.tokens.null['100'],
          disable: _index.tokens.null['100']
        }
      },
      text: {
        color: {
          default: theme.content.base,
          hover: theme.content.base,
          active: theme.content.base,
          disabel: theme.contentState.base.disable
        }
      },
      icon: {
        color: {
          default: theme.content.base,
          hover: theme.content.base,
          active: theme.content.base,
          disabel: theme.contentState.base.disable
        }
      }
    },
    alternative: {
      container: {
        color: {
          default: theme.background.dark,
          hover: theme.backgroundState.dark.hover,
          active: theme.backgroundState.dark.active,
          disable: theme.backgroundState.dark.disable
        },
        border: {
          default: _index.tokens.null['100'],
          hover: _index.tokens.null['100'],
          active: _index.tokens.null['100'],
          disable: _index.tokens.null['100']
        }
      },
      text: {
        color: {
          default: theme.content.baseInverse,
          hover: theme.content.baseInverse,
          active: theme.content.baseInverse,
          disabel: theme.contentState.baseInverse.disable
        }
      },
      icon: {
        color: {
          default: theme.content.baseInverse,
          hover: theme.content.baseInverse,
          active: theme.content.baseInverse,
          disabel: theme.contentState.baseInverse.disable
        }
      }
    },
    outline: {
      container: {
        color: {
          default: _index.tokens.null['100'],
          hover: _index.tokens.null['100'],
          active: _index.tokens.null['100'],
          disable: _index.tokens.null['100']
        },
        border: {
          default: theme.border.dark,
          hover: theme.borderState.dark.hover,
          active: theme.borderState.dark.active,
          disable: theme.borderState.dark.disable
        }
      },
      text: {
        color: {
          default: theme.content.base,
          hover: theme.contentState.base.hover,
          active: theme.contentState.base.active,
          disabel: theme.contentState.base.disable
        }
      },
      icon: {
        color: {
          default: theme.content.base,
          hover: theme.contentState.base.hover,
          active: theme.contentState.base.active,
          disabel: theme.contentState.base.disable
        }
      }
    },
    ghost: {
      container: {
        color: {
          default: _index.tokens.null['100'],
          hover: _index.tokens.null['100'],
          active: _index.tokens.null['100'],
          disable: _index.tokens.null['100']
        },
        border: {
          default: _index.tokens.null['100'],
          hover: _index.tokens.null['100'],
          active: _index.tokens.null['100'],
          disable: _index.tokens.null['100']
        }
      },
      text: {
        color: {
          default: theme.content.base,
          hover: theme.contentState.base.hover,
          active: theme.contentState.base.active,
          disabel: theme.contentState.base.disable
        }
      },
      icon: {
        color: {
          default: theme.content.base,
          hover: theme.contentState.base.hover,
          active: theme.contentState.base.active,
          disabel: theme.contentState.base.disable
        }
      }
    }
  },
  input: {
    icon: {
      size: '20px'
    },
    paddingHorizontal: _index.tokens.padding.M,
    paddingVertical: _index.tokens.padding.S,
    gap: _index.tokens.padding.S,
    contentGap: _index.tokens.padding.XS,
    requiredGap: _index.tokens.padding.XXXS,
    borderRadius: _index.tokens.borderRadius.XS,
    fieldLabel: theme.desktop.input.secondary,
    required: theme.desktop.input.secondary,
    inputPlaceholder: theme.desktop.input.primary,
    error: theme.desktop.input.secondary,
    grey: {
      container: {
        color: {
          default: theme.background.weak,
          filled: theme.background.weak,
          focus: theme.background.weak,
          error: theme.background.weak,
          errorFilled: theme.background.weak,
          disable: theme.background.weak
        },
        border: {
          default: _index.tokens.null['100'],
          filled: _index.tokens.null['100'],
          focus: theme.border.focus,
          error: theme.border.danger,
          errorFilled: theme.border.danger,
          disable: _index.tokens.null['100']
        }
      },
      text: {
        color: {
          fieldLabel: {
            default: theme.content.base,
            filled: theme.content.weak,
            focus: theme.content.weak,
            error: theme.content.weak,
            errorFilled: theme.content.danger,
            disable: theme.contentState.weak.disable
          },
          inputPlaceholder: {
            default: theme.content.weak,
            filled: theme.content.base,
            focus: theme.content.base,
            error: theme.content.base,
            errorFilled: theme.content.base,
            disable: theme.contentState.weak.disable
          },
          required: {
            default: theme.content.danger,
            filled: theme.content.danger,
            focus: theme.content.danger,
            error: theme.content.danger,
            errorFilled: theme.content.danger,
            disable: theme.contentState.weak.disable
          },
          errorMessage: {
            error: theme.content.danger,
            errorFilled: theme.content.danger
          }
        }
      },
      icon: {
        color: {
          default: theme.content.accent,
          filled: theme.content.accent,
          focus: theme.content.accent,
          error: theme.content.danger,
          errorFilled: theme.content.danger,
          disable: theme.contentState.weak.disable
        }
      }
    },
    border: {
      container: {
        color: {
          default: theme.background.base,
          filled: theme.background.base,
          focus: theme.background.base,
          error: theme.background.base,
          errorFilled: theme.background.base,
          disable: theme.background.base
        },
        border: {
          default: theme.border.subtle,
          filled: theme.border.subtle,
          focus: theme.border.focus,
          error: theme.border.danger,
          errorFilled: theme.border.danger,
          disable: theme.border.subtle
        }
      },
      text: {
        color: {
          fieldLabel: {
            default: theme.content.base,
            filled: theme.content.weak,
            focus: theme.content.weak,
            error: theme.content.weak,
            errorFilled: theme.content.danger,
            disable: theme.contentState.weak.disable
          },
          inputPlaceholder: {
            default: theme.content.weak,
            filled: theme.content.base,
            focus: theme.content.base,
            error: theme.content.base,
            errorFilled: theme.content.base,
            disable: theme.contentState.weak.disable
          },
          required: {
            default: theme.content.danger,
            filled: theme.content.danger,
            focus: theme.content.danger,
            error: theme.content.danger,
            errorFilled: theme.content.danger,
            disable: theme.contentState.weak.disable
          },
          errorMessage: {
            error: theme.content.danger,
            errorFilled: theme.content.danger
          }
        }
      },
      icon: {
        color: {
          default: theme.content.accent,
          filled: theme.content.accent,
          focus: theme.content.accent,
          error: theme.content.danger,
          errorFilled: theme.content.danger,
          disable: theme.contentState.weak.disable
        }
      }
    }
  },
  dropdown: {
    icon: {
      size: '20px'
    },
    paddingHorizontal: _index.tokens.padding.M,
    paddingVertical: _index.tokens.padding.S,
    gap: _index.tokens.padding.S,
    contentGap: _index.tokens.padding.XS,
    requiredGap: _index.tokens.padding.XXXS,
    grey: {
      container: {
        color: {
          default: theme.background.weak,
          filled: theme.background.weak,
          focus: theme.background.weak,
          error: theme.background.weak,
          errorFilled: theme.background.weak,
          disable: theme.background.weak
        },
        border: {
          default: _index.tokens.null['100'],
          filled: _index.tokens.null['100'],
          focus: theme.border.focus,
          error: theme.border.danger,
          errorFilled: theme.border.danger,
          disable: _index.tokens.null['100']
        }
      },
      text: {
        color: {
          fieldLabel: {
            default: theme.content.base,
            filled: theme.content.weak,
            focus: theme.content.weak,
            error: theme.content.weak,
            errorFilled: theme.content.danger,
            disable: theme.contentState.weak.disable
          },
          inputPlaceholder: {
            default: theme.content.weak,
            filled: theme.content.base,
            focus: theme.content.base,
            error: theme.content.base,
            errorFilled: theme.content.base,
            disable: theme.contentState.weak.disable
          },
          required: {
            default: theme.content.danger,
            filled: theme.content.danger,
            focus: theme.content.danger,
            error: theme.content.danger,
            errorFilled: theme.content.danger,
            disable: theme.contentState.weak.disable
          },
          errorMessage: {
            error: theme.content.danger,
            errorFilled: theme.content.danger
          }
        }
      },
      icon: {
        color: {
          default: theme.content.accent,
          filled: theme.content.accent,
          focus: theme.content.accent,
          error: theme.content.danger,
          errorFilled: theme.content.danger,
          disable: theme.contentState.weak.disable
        }
      }
    },
    border: {
      container: {
        color: {
          default: theme.background.base,
          filled: theme.background.base,
          focus: theme.background.base,
          error: theme.background.base,
          errorFilled: theme.background.base,
          disable: theme.background.base
        },
        border: {
          default: theme.border.subtle,
          filled: theme.border.subtle,
          focus: theme.border.focus,
          error: theme.border.danger,
          errorFilled: theme.border.danger,
          disable: theme.border.subtle
        }
      },
      text: {
        color: {
          fieldLabel: {
            default: theme.content.base,
            filled: theme.content.weak,
            focus: theme.content.weak,
            error: theme.content.weak,
            errorFilled: theme.content.danger,
            disable: theme.contentState.weak.disable
          },
          inputPlaceholder: {
            default: theme.content.weak,
            filled: theme.content.base,
            focus: theme.content.base,
            error: theme.content.base,
            errorFilled: theme.content.base,
            disable: theme.contentState.weak.disable
          },
          required: {
            default: theme.content.danger,
            filled: theme.content.danger,
            focus: theme.content.danger,
            error: theme.content.danger,
            errorFilled: theme.content.danger,
            disable: theme.contentState.weak.disable
          },
          errorMessage: {
            error: theme.content.danger,
            errorFilled: theme.content.danger
          }
        }
      },
      icon: {
        color: {
          default: theme.content.accent,
          filled: theme.content.accent,
          focus: theme.content.accent,
          error: theme.content.danger,
          errorFilled: theme.content.danger,
          disable: theme.contentState.weak.disable
        }
      }
    },
    borderRadius: _index.tokens.borderRadius.XS,
    fieldLabel: theme.desktop.input.secondary,
    error: theme.desktop.input.secondary,
    inputPlaceholder: theme.desktop.input.primary,
    required: theme.desktop.input.secondary
  },
  select: {
    paddingHorizontal: _index.tokens.padding.M,
    paddingVertical: _index.tokens.padding.M,
    container: {
      color: {
        default: theme.background.base,
        hover: theme.background.accentLight,
        active: theme.background.accentLight,
        header: theme.background.weak,
        disable: theme.background.base
      }
    },
    text: {
      color: {
        default: theme.content.base,
        hover: theme.content.base,
        active: theme.content.base,
        header: theme.content.base,
        disable: theme.contentState.base.disable
      }
    },
    gap: '0px',
    borderRadius: _index.tokens.borderRadius.XS,
    fieldLabel: theme.desktop.body.secondary
  },
  radioButton: {
    gap: '8px',
    circle: {
      color: {
        default: theme.border.dark,
        hover: theme.border.dark,
        selected: theme.border.dark,
        focus: theme.border.dark,
        error: theme.border.danger,
        disableSelected: theme.borderState.dark.disable,
        disable: theme.borderState.dark.disable
      }
    },
    innerCircle: {
      color: {
        default: _index.tokens.null['100'],
        hover: theme.backgroundState.dark.hover,
        selected: theme.background.dark,
        focus: theme.background.dark,
        error: _index.tokens.null['100'],
        disableSelected: theme.backgroundState.dark.disable,
        disable: _index.tokens.null['100']
      }
    },
    focus: {
      color: {
        default: _index.tokens.null['100'],
        hover: _index.tokens.null['100'],
        selected: _index.tokens.null['100'],
        focus: theme.border.accent,
        error: _index.tokens.null['100'],
        selectedDisable: _index.tokens.null['100'],
        disable: _index.tokens.null['100']
      }
    },
    text: {
      color: {
        textLabel: {
          default: theme.content.base,
          hover: theme.content.base,
          selected: theme.content.base,
          focus: theme.content.base,
          error: theme.content.base,
          disableSelected: theme.contentState.base.disable,
          disable: theme.contentState.base.disable
        },
        errorLabel: {
          default: _index.tokens.null['100'],
          hover: _index.tokens.null['100'],
          selected: _index.tokens.null['100'],
          focus: _index.tokens.null['100'],
          error: theme.content.danger,
          disableSelected: _index.tokens.null['100'],
          disable: _index.tokens.null['100']
        }
      }
    },
    fieldLabel: theme.desktop.label.secondary,
    errorLabel: theme.desktop.label.tertiary
  },
  checkbox: {
    gap: '8px',
    square: {
      color: {
        default: theme.border.dark,
        hover: theme.border.dark,
        selected: theme.border.dark,
        hoverSelected: theme.border.dark,
        focus: theme.border.dark,
        error: theme.border.danger,
        disableSelected: theme.borderState.dark.disable,
        disable: theme.borderState.dark.disable
      }
    },
    innerSquare: {
      color: {
        default: _index.tokens.null['100'],
        hover: theme.backgroundState.dark.hover,
        selected: theme.background.dark,
        hoverSelected: theme.backgroundState.dark.hover,
        focus: theme.background.dark,
        error: _index.tokens.null['100'],
        disableSelected: theme.backgroundState.dark.disable,
        disable: _index.tokens.null['100']
      }
    },
    focus: {
      color: {
        default: _index.tokens.null['100'],
        hover: _index.tokens.null['100'],
        selected: _index.tokens.null['100'],
        hoverSelected: _index.tokens.null['100'],
        focus: theme.border.accent,
        error: _index.tokens.null['100'],
        selectedDisable: _index.tokens.null['100'],
        disable: _index.tokens.null['100']
      }
    },
    checkmark: {
      color: {
        default: _index.tokens.null['100'],
        hover: _index.tokens.null['100'],
        selected: theme.background.base,
        hoverSelected: theme.background.base,
        focus: theme.background.base,
        error: _index.tokens.null['100'],
        selectedDisable: theme.backgroundState.base.disable,
        disable: _index.tokens.null['100']
      }
    },
    text: {
      color: {
        textLabel: {
          default: theme.content.base,
          hover: theme.content.base,
          selected: theme.content.base,
          hoverSelected: theme.content.base,
          focus: theme.content.base,
          error: theme.content.base,
          disableSelected: theme.contentState.base.disable,
          disable: theme.contentState.base.disable
        },
        errorLabel: {
          default: _index.tokens.null['100'],
          hover: _index.tokens.null['100'],
          selected: _index.tokens.null['100'],
          hoverSelected: _index.tokens.null['100'],
          focus: _index.tokens.null['100'],
          error: theme.content.danger,
          disableSelected: _index.tokens.null['100'],
          disable: _index.tokens.null['100']
        }
      }
    },
    fieldLabel: theme.desktop.label.secondary,
    errorLabel: theme.desktop.label.tertiary
  },
  segmentControl: {
    paddingHorizontal: _index.tokens.padding.M,
    paddingVertical: _index.tokens.padding['M+'],
    gap: '0px',
    container: {
      color: {
        default: theme.background.base,
        pressed: theme.background.accentLight
      }
    },
    text: {
      color: {
        default: theme.content.base,
        pressed: theme.content.base
      }
    },
    border: {
      color: {
        default: theme.border.subtle,
        pressed: theme.border.subtle
      }
    },
    fieldLabel: theme.desktop.label.secondary
  },
  tabs: {
    basic: {
      paddingHorizontal: _index.tokens.padding['L+'],
      paddingVertical: _index.tokens.padding['M+'],
      gap: _index.tokens.padding.XS,
      container: {
        color: {
          default: _index.tokens.null['100'],
          hover: _index.tokens.null['100'],
          active: _index.tokens.null['100'],
          disable: _index.tokens.null['100']
        }
      },
      text: {
        color: {
          default: theme.content.subtle,
          active: theme.content.base,
          hover: theme.content.base,
          disable: theme.contentState.base.disable
        }
      },
      border: {
        color: {
          default: _index.tokens.null['100'],
          hover: theme.border.accent,
          active: theme.border.base,
          disable: _index.tokens.null['100']
        }
      },
      borderRadius: _index.tokens.borderRadius.XS,
      fieldLabel: theme.desktop.label.secondary,
      outsideBorder: {
        color: {
          generic: theme.border.subtle
        }
      }
    },
    card: {
      paddingHorizontal: _index.tokens.padding['L+'],
      paddingVertical: _index.tokens.padding['M+'],
      gap: '0px',
      container: {
        color: {
          default: theme.background.subtle,
          hover: theme.background.base,
          active: theme.background.weak,
          disable: theme.background.base
        }
      },
      text: {
        color: {
          default: theme.content.subtle,
          active: theme.content.base,
          hover: theme.content.base,
          disable: theme.contentState.base.disable
        }
      },
      border: {
        color: {
          default: _index.tokens.null['100'],
          hover: _index.tokens.null['100'],
          active: _index.tokens.null['100'],
          disable: _index.tokens.null['100']
        }
      },
      borderRadius: _index.tokens.borderRadius.XS,
      fieldLabel: theme.desktop.label.secondary,
      outsideBorder: {
        color: {
          generic: _index.tokens.null['100']
        }
      }
    }
  },
  accordion: {
    icon: {
      size: '24px',
      color: {
        default: theme.content.base,
        hover: theme.content.base,
        disable: theme.contentState.base.disable
      }
    },
    header: {
      paddingHorizontal: _index.tokens.padding.L,
      paddingVertical: _index.tokens.padding.L,
      gap: _index.tokens.padding.S,
      color: {
        default: _index.tokens.null['100'],
        hover: theme.background.subtle,
        disable: _index.tokens.null['100']
      }
    },
    content: {
      paddingHorizontal: _index.tokens.padding.L,
      paddingVertical: _index.tokens.padding.M,
      gap: _index.tokens.padding.L,
      color: {
        default: _index.tokens.null['100'],
        hover: _index.tokens.null['100']
      }
    },
    text: {
      color: {
        title: {
          default: theme.content.base,
          hover: theme.content.base,
          disable: theme.contentState.base.disable
        },
        content: {
          default: theme.content.subtle,
          hover: theme.content.subtle
        }
      }
    },
    border: {
      color: {
        default: theme.border.weak,
        hover: theme.border.weak,
        disable: theme.border.weak
      }
    },
    headerLabel: theme.desktop.label.secondary,
    contentLabel: theme.desktop.body.secondary
  },
  accordions: {
    borderRadius: _index.tokens.borderRadius.XS
  }
};
exports.components = components;